import type { LanguageInput } from 'shiki'
import manifest from '../vendor/shiki/manifest.json'

export type AvailableLanguage = keyof typeof manifest.langs

export const Languages = Object.keys(manifest.langs).reduce((acc, lang) => {
  const key = lang.replace(/-/g, '_').toUpperCase()
  return { ...acc, [key]: lang as AvailableLanguage }
}, {} as Record<string, AvailableLanguage>)

export async function getLanguage(langName: AvailableLanguage): Promise<LanguageInput> {
  try {
    const lang = await import(`../vendor/shiki/langs/${String(langName)}.js`)
    return lang.default
  }
  catch (err) {
    const error = err instanceof Error ? err.message : String(err)
    throw new Error(`Language '${String(langName)}' failed to load: ${error}`)
  }
}
