import type { ThemeInput } from 'shiki'
import manifest from '../vendor/shiki/manifest.json'

export type AvailableTheme = keyof typeof manifest.themes

export const Themes = Object.keys(manifest.themes).reduce<Record<string, AvailableTheme>>((acc, theme) => {
  const key = (theme as AvailableTheme).replace(/-/g, '_').toUpperCase()
  return { ...acc, [key]: theme as AvailableTheme }
}, {} as Record<string, AvailableTheme>)

export async function getTheme(themeName: AvailableTheme): Promise<ThemeInput> {
  try {
    const theme = await import(`../vendor/shiki/themes/${String(themeName)}.js`)
    return theme.default
  }
  catch (err) {
    const error = err instanceof Error ? err.message : String(err)
    throw new Error(`Theme '${String(themeName)}' failed to load: ${error}`)
  }
}
